OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Chaidh am faidhle a luchdadh suas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tha am faidhle a luchdaich thu suas a’ dol thairis air an riaghailt upload_max_filesize ann am php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tha am faidhle a luchdaich thu suas a’ dol thairis air an riaghailt MAX_FILE_SIZE a chaidh a shònrachadh san fhoirm HTML",
    "The file was only partially uploaded" : "Cha deach ach pàirt dhen fhaidhle a luchdadh suas",
    "No file was uploaded" : "Cha deach faidhle sam bith a luchdadh suas",
    "Missing a temporary folder" : "Tha pasgan sealach a dhìth",
    "Could not write file to disk" : "Cha b’ urrainn dhuinn am faidhle a sgrìobhadh dhan diosg",
    "A PHP extension stopped the file upload" : "Chur leudachan PHP stad air luchdadh suas an fhaidhle",
    "Translate" : "Eadar-theangaich",
    "Cancel" : "Sguir dheth",
    "Replace" : "Cuir ’na àite",
    "Source code" : "Bun-tùs",
    "Undo" : "Neo-dhèan",
    "Edit" : "Deasaich"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
